@@ -27,8 +27,8 @@
 
 #include <kdebug.h>
 #include <kinputdialog.h> 
-#include <klocale.h>
-#include <kmessagebox.h>
+#include <tdelocale.h>
+#include <tdemessagebox.h>
 #include <tqregexp.h>
 #include <tqtimer.h> 
 
@@ -36,7 +36,7 @@
 CircuitDocument::CircuitDocument( const TQString & caption, KTechlab *ktechlab, const char *name )
 	: ICNDocument( caption, ktechlab, name )
 {
-	m_pOrientationAction = new KActionMenu( i18n("Orientation"), "rotate", this );
+	m_pOrientationAction = new TDEActionMenu( i18n("Orientation"), "rotate", this );
 	
 	m_type = Document::dt_circuit;
 	m_pDocumentIface = new CircuitDocumentIface(this);
@@ -84,7 +84,7 @@ void CircuitDocument::slotInitItemActions( Item *itemBase )
 	if ( !item && m_selectList->count() > 0 || !m_selectList->itemsAreSameType() )
 		return;
 	
-	KAction * orientation_actions[] = {
+	TDEAction * orientation_actions[] = {
 		activeCircuitView->action("edit_orientation_0"),
 		activeCircuitView->action("edit_orientation_90"),
 		activeCircuitView->action("edit_orientation_180"),
@@ -105,16 +105,16 @@ void CircuitDocument::slotInitItemActions( Item *itemBase )
 	}
 	
 	if ( item->angleDegrees() == 0 )
-		(static_cast<KToggleAction*>( orientation_actions[0] ))->setChecked(true);
+		(static_cast<TDEToggleAction*>( orientation_actions[0] ))->setChecked(true);
 	
 	else if ( item->angleDegrees() == 90 )
-		(static_cast<KToggleAction*>( orientation_actions[1] ))->setChecked(true);
+		(static_cast<TDEToggleAction*>( orientation_actions[1] ))->setChecked(true);
 	
 	else if ( item->angleDegrees() == 180 )
-		(static_cast<KToggleAction*>( orientation_actions[2] ))->setChecked(true);
+		(static_cast<TDEToggleAction*>( orientation_actions[2] ))->setChecked(true);
 	
 	else if ( item->angleDegrees() == 270 )
-		(static_cast<KToggleAction*>( orientation_actions[3] ))->setChecked(true);
+		(static_cast<TDEToggleAction*>( orientation_actions[3] ))->setChecked(true);
 }
 
 
@@ -209,7 +209,7 @@ void CircuitDocument::fillContextMenu( const TQPoint &pos )
 	//logic was --electronerd
 	if (!( !item && m_selectList->count() > 0 || !m_selectList->itemsAreSameType() ))
 	{	
-		KAction * orientation_actions[] = {
+		TDEAction * orientation_actions[] = {
 			activeCircuitView->action("edit_orientation_0"),
 			activeCircuitView->action("edit_orientation_90"),
 			activeCircuitView->action("edit_orientation_180"),
@@ -224,16 +224,16 @@ void CircuitDocument::fillContextMenu( const TQPoint &pos )
 			m_pOrientationAction->insert( orientation_actions[i] );
 		}
 		
-		TQPtrList<KAction> orientation_actionlist;
-	// 	orientation_actionlist.prepend( new KActionSeparator() );
+		TQPtrList<TDEAction> orientation_actionlist;
+	// 	orientation_actionlist.prepend( new TDEActionSeparator() );
 		orientation_actionlist.append( m_pOrientationAction );
 		p_ktechlab->plugActionList( "orientation_actionlist", orientation_actionlist );
 	}
 	
 	if(m_selectList->count() > 1 && countExtCon(m_selectList->items()) > 0)
 	{
-		TQPtrList<KAction> component_actionlist;
-	// 	component_actionlist.append( new KActionSeparator() );
+		TQPtrList<TDEAction> component_actionlist;
+	// 	component_actionlist.append( new TDEActionSeparator() );
 		component_actionlist.append( activeCircuitView->action("circuit_create_subcircuit") );
 		p_ktechlab->plugActionList( "component_actionlist", component_actionlist );
 	}
